import {Component} from '@angular/core';
import {IonicPage, NavController, NavParams, AlertController, ToastController} from 'ionic-angular';

import {Http, Response} from '@angular/http';
import {Storage} from '@ionic/storage';
import {ReportSearchPage} from "../report-search/report-search";
import {AppService,AppGlobal} from "../../../../service/appHttpService";

@IonicPage()
@Component({
    selector: 'page-reportDetail',
    templateUrl: 'reportDetail.html',
})
export class ReportDetailPage {

    items: object[] = [];
    itemsOfNotReport: object[] = [];
    itemsOfLeave: object[] = [];
    itemsOfNotLeave: object[] = [];
    title: string;
    type: number;
    id;
    picture: string = AppGlobal.picture;
    premanager; //报备信息

    constructor(public navCtrl: NavController,
                public navParams: NavParams,
                public alertCtrl: AlertController,
                public http: Http, public storage: Storage,
                public appService: AppService, public toast: ToastController) {


    }

    ionViewDidLoad() {
        this.premanager = this.navParams.get('item');
        this.title = this.navParams.get("title");
        this.id = this.navParams.get("id");
    }

    ionViewDidEnter() {
        this.getUserAboutLeave(this.id);
        this.getUserAboutNotLeave(this.id);
        this.getUserAboutNotReport(this.id);
    }

    //获取处室下所有未报备人员
    getUserAboutNotReport(id) {
        this.appService.ObserverHttpPost("/wisdomgroup/modules/premanager/getUserAboutNotReport", {id: id})
            .subscribe((res: Response) => {
                    let data = res.json();
                    this.itemsOfNotReport = data;
                    this.items = data;
                    this.type = 1;
                }, error => {
                }
            );
    }

    //获取处室下所有离沪报备人员
    getUserAboutLeave(id) {
        this.appService.ObserverHttpPost("/wisdomgroup/modules/premanager/getUserAboutLeave", {id: id})
            .subscribe((res: Response) => {
                    let data = res.json();
                    this.itemsOfLeave = data;
                }, error => {
                }
            );
    }

    //获取处室下所有不离沪报备人员
    getUserAboutNotLeave(id) {
        this.appService.ObserverHttpPost("/wisdomgroup/modules/premanager/getUserAboutNotLeave", {id: id})
            .subscribe((res: Response) => {
                    let data = res.json();
                    this.itemsOfNotLeave = data;
                }, error => {
                }
            );
    }

    //切换
    change(type) {
        if (type == 1) {
            this.type = type;
            this.items = this.itemsOfNotReport;
        } else if (type == 2) {
            this.type = type;
            this.items = this.itemsOfLeave;
        } else if (type == 3) {
            this.type = type;
            this.items = this.itemsOfNotLeave;
        }
    }

    //协助报备
    goReport(item) {
        this.storage.remove("temp_userpre");
        this.storage.remove("managerId");
        this.storage.remove("city");
        this.storage.remove("cityList");
        this.storage.remove("person");
        this.storage.set('premanager', this.premanager);
        this.storage.set('person', item);
        this.navCtrl.push('OutGoingReportEditPage', {premanager: 'null'});
    }

    //修改报备
    editReport(item){
        this.storage.remove("temp_userpre");
        this.storage.remove("managerId");
        this.storage.remove("city");
        this.storage.remove("cityList");
        this.storage.remove("person");
        this.storage.set('premanager', this.premanager);
        this.storage.set('person', item);
        this.navCtrl.push('OutGoingReportEditPage', {premanager: 'null',userid:item.id});
    }


    search(){
        this.navCtrl.push('ReportSearchPage',{id:this.id,'premanager':this.premanager});
    }
}
